tiled.client.xarray.DataArrayClient
===================================

.. currentmodule:: tiled.client.xarray

.. autoclass:: DataArrayClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataArrayClient.__init__
      ~DataArrayClient.download
      ~DataArrayClient.export_all
      ~DataArrayClient.export_array
      ~DataArrayClient.new_variation
      ~DataArrayClient.read
      ~DataArrayClient.read_block
      ~DataArrayClient.refresh
      ~DataArrayClient.structure
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DataArrayClient.context
      ~DataArrayClient.coords
      ~DataArrayClient.item
      ~DataArrayClient.metadata
      ~DataArrayClient.offline
      ~DataArrayClient.path
      ~DataArrayClient.uri
      ~DataArrayClient.username
   
   